Class: Ductwork::AbandonedClaim

Inherits:
Crash
  • Object
show all
Defined in:
lib/ductwork/abandoned_claim.rb

Overview

A work loop exited an iteration with an uncommitted claim without raising a StandardError -- a non-StandardError exception (a signal, Thread#kill), a non-local exit, or a rescue path that itself failed to commit.